==> campsite-2.4.1.tar.gz: campsite/implementation/management/priv/lang/en/api.php <==
<?php
regGS("The IP address group $1 has been deleted.", "The IP address group $1 has been deleted.");
regGS("IP Group $1 added for user $2", "IP Group $1 added for user $2");
regGS("User permissions for $1 changed", "User permissions for $1 changed");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "Section $1 deleted. (Issue: $2, Publication: $3)");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "Section $1 added. (Issue: $2, Publication: $3)");
regGS("Issue $1 changed status to $2", "Issue $1 changed status to $2");
regGS("User type $1 deleted", "User type $1 deleted");
regGS("User type $1 added", "User type $1 added");
regGS("Topic $1 added to article", "Topic $1 added to article");
regGS("Last", "Last");
regGS("First", "First");
regGS("Changed image properties of $1", "Changed image properties of $1");
regGS("Article topic $1 deleted", "Article topic $1 deleted");
regGS("Article #$1 \"$2\" ($3) created.", "Article #$1 \"$2\" ($3) created.");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "Article #$1 \"$2\" ($3) translated to \"$5\" ($4)");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "Article #$1 \"$2\" ($3) copied to Article #$3. ");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "Article #$1: \"$2\" status changed from $3 to $4.");
regGS("Article #$1: \"$2\" ($3) deleted.", "Article #$1: \"$2\" ($3) deleted.");
regGS("Text", "Text");
regGS("Article body", "Article body");
regGS("The default subscription time for $1 has been added.", "The default subscription time for $1 has been added.");
regGS("Image $1 linked to article $2", "Image $1 linked to article $2");
regGS("Image $1 unlinked from $2", "Image $1 unlinked from $2");
regGS("The image $1 has been added.", "The image $1 has been added.");
regGS("Image $1 deleted", "Image $1 deleted");
regGS("Publication $1 changed", "Publication $1 changed");
regGS("Publication $1 deleted", "Publication $1 deleted");
regGS("Publication $1 added", "Publication $1 added");
regGS("Issue $1 from publication $2 deleted", "Issue $1 from publication $2 deleted");
regGS("Issue $1 added in publication $2", "Issue $1 added in publication $2");
regGS("The article type $1 has been deleted.", "The article type $1 has been deleted.");
regGS("The article type $1 has been added.", "The article type $1 has been added.");
regGS("Article type field $1 created", "Article type field $1 created");
regGS("Article type field $1 deleted", "Article type field $1 deleted");
regGS("Language $1 added", "Language $1 added");
regGS("Language $1 deleted", "Language $1 deleted");
regGS("Language $1 modified", "Language $1 modified");
regGS("Country $1 added", "Country $1 added");
regGS("Country $1 deleted", "Country $1 deleted");
regGS("Country name $1 changed", "Country name $1 changed");
regGS("The user account $1 has been deleted.", "The user account $1 has been deleted.");
regGS("Password changed for $1", "Password changed for $1");
regGS("User account $1 created", "User account $1 created");
regGS("Template $1 uploaded", "Template $1 uploaded");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/en/api.php <==
<?php 
regGS("Template $1 no longer exists!", "Template $1 no longer exists!");
regGS("The file uploaded is not an image.", "The file uploaded is not an image.");
regGS("Field $1 updated", "Field $1 updated");
regGS("Could not delete record from the database.", "Could not delete record from the database.");
regGS("template path", "template path");
regGS("short names", "short names");
regGS("Unable to fetch image from remote server.", "Unable to fetch image from remote server.");
regGS("The article type field $1 has been renamed to $2.", "The article type field $1 has been renamed to $2.");
regGS("The article type $1 has been renamed to $2.", "The article type $1 has been renamed to $2.");
regGS("Article type field $1 changed", "Article type field $1 changed");
regGS("Article Type $1 translation updated", "Article Type $1 translation updated");
regGS("The IP address group $1 has been deleted.", "The IP address group $1 has been deleted.");
regGS("IP Group $1 added for user $2", "IP Group $1 added for user $2");
regGS("User permissions for $1 changed", "User permissions for $1 changed");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "Section $1 deleted. (Issue: $2, Publication: $3)");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "Section $1 added. (Issue: $2, Publication: $3)");
regGS("Issue $1 changed status to $2", "Issue $1 changed status to $2");
regGS("User type $1 deleted", "User type $1 deleted");
regGS("User type $1 added", "User type $1 added");
regGS("Topic $1 added to article", "Topic $1 added to article");
regGS("Last", "Last");
regGS("First", "First");
regGS("Changed image properties of $1", "Changed image properties of $1");
regGS("Article topic $1 deleted", "Article topic $1 deleted");
regGS("Article #$1 \"$2\" ($3) created.", "Article #$1 \"$2\" ($3) created.");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "Article #$1 \"$2\" ($3) translated to \"$5\" ($4)");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "Article #$1 \"$2\" ($3) copied to Article #$3. ");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "Article #$1: \"$2\" status changed from $3 to $4.");
regGS("Article #$1: \"$2\" ($3) deleted.", "Article #$1: \"$2\" ($3) deleted.");
regGS("Single-line Text", "Single-line Text");
regGS("Multi-line Text with WYSIWYG", "Multi-line Text with WYSIWYG");
regGS("The default subscription time for $1 has been added.", "The default subscription time for $1 has been added.");
regGS("Image $1 linked to article $2", "Image $1 linked to article $2");
regGS("Image $1 unlinked from $2", "Image $1 unlinked from $2");
regGS("The image $1 has been added.", "The image $1 has been added.");
regGS("Image $1 deleted", "Image $1 deleted");
regGS("Publication $1 changed", "Publication $1 changed");
regGS("Publication $1 deleted", "Publication $1 deleted");
regGS("Publication $1 added", "Publication $1 added");
regGS("Issue $1 from publication $2 deleted", "Issue $1 from publication $2 deleted");
regGS("Issue $1 added in publication $2", "Issue $1 added in publication $2");
regGS("The article type $1 has been deleted.", "The article type $1 has been deleted.");
regGS("The article type $1 has been added.", "The article type $1 has been added.");
regGS("Article type field $1 created", "Article type field $1 created");
regGS("Article type field $1 deleted", "Article type field $1 deleted");
regGS("Language $1 added", "Language $1 added");
regGS("Language $1 deleted", "Language $1 deleted");
regGS("Language $1 modified", "Language $1 modified");
regGS("Country $1 added", "Country $1 added");
regGS("Country $1 deleted", "Country $1 deleted");
regGS("Country name $1 changed", "Country name $1 changed");
regGS("The user account $1 has been deleted.", "The user account $1 has been deleted.");
regGS("Password changed for $1", "Password changed for $1");
regGS("User account $1 created", "User account $1 created");
regGS("Template $1 uploaded", "Template $1 uploaded");
regGS("URL \"$1\" is invalid or is not an image.", "URL \"$1\" is invalid or is not an image.");
regGS("URL \"$1\" is not an image.", "URL \"$1\" is not an image.");
regGS("Topic $1 added", "Topic $1 added");
regGS("Topic $1 deleted", "Topic $1 deleted");
regGS("Topic $1 updated", "Topic $1 updated");
?>
